#
# spec file for package hashcat
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libhashcat6_2_6
Name:           hashcat
Version:        6.2.6
Release:        bp156.1.4
Summary:        CPU-based password recovery utility
License:        GPL-2.0-or-later AND MIT
Group:          Productivity/Security
URL:            https://hashcat.net/
Source:         https://hashcat.net/files/%name-%version.tar.gz
Source2:        https://hashcat.net/files/%name-%version.tar.gz.asc
#  Key ID: 2048R/8A16544F. Fingerprint: A708 3322 9D04 0B41 99CC 0052 3C17 DA8B 8A16 544F
Source3:        %name.keyring
Source9:        %name-rpmlintrc
Patch1:         system-libs.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  xxhash-devel
BuildRequires:  pkgconfig(clzma)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(zlib)
ExclusiveArch:  %ix86 x86_64

%description
Hashcat is a password recovery utility, supporting seven
unique modes of testing for over 100 optimized hashing algorithms.

GPU Driver requirements:

 * AMD GPUs on Linux require "RadeonOpenCompute (ROCm)" Software
   Platform (3.1 or later)
 * AMD GPUs on Windows require "AMD Radeon Adrenalin 2020
   Edition" (20.2.2 or later)
 * Intel and AMD CPUs require "OpenCL Runtime for Intel Core and
   Intel Xeon Processors" (16.1.1 or later)
 * NVIDIA GPUs require "NVIDIA Driver" (440.64 or later) and
   "CUDA Toolkit" (9.0 or later)

%package -n %lname
Summary:        Implementation of the hashcat engine
Group:          System/Libraries

%description -n %lname
Hashcat is a password recovery utility, supporting seven
unique modes of testing for over 100 optimized hashing algorithms.

%package devel
Summary:        Header files for making hashcat plugins
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Hashcat is a password recovery utility, supporting seven
unique modes of testing for over 100 optimized hashing algorithms.

This subpackage contains the header files.

%prep
%autosetup -p1
find . -name .lock -type f -delete

%build
%global margs DOCUMENT_FOLDER="%_docdir/%name" our_CFLAGS="%optflags" LIBRARY_FOLDER="%_libdir"
%make_build %margs

%install
%make_install %margs
b="%buildroot"
ln -s libhashcat.so.%version "$b/%_libdir/libhashcat.so"
# fix stupid placement of arch-dep files
mkdir "$b/%_libdir/%name"
mv "$b/%_datadir/%name/modules" "$b/%_libdir/%name/"
ln -s "%_libdir/%name/modules" "$b/%_datadir/%name/"
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%doc README.md
%_bindir/hashcat
%_docdir/%name/
%_libdir/%name/
%_datadir/%name/

%files -n %lname
%_libdir/libhashcat.so.%version

%files devel
%_includedir/hashcat/
%_libdir/libhashcat.so

%changelog
* Sun May  7 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to 6.2.6:
  * many new hash-modes and bug fixes
- add upstream signing key and verify source signature
* Wed Feb 23 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 6.2.5
  * This release adds improved HIP compatibility, several new
    hash-modes, and bug fixes.
* Sat May 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 6.2.1
  * Build procedure changes allowing not to use unrar
* Fri May 14 2021 Martin Hauke <mardnh@gmx.de>
- Use correct lname
* Fri May 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 6.2.0
  * This release is mostly about expanding support for new
    algorithms and fixing bugs.
  * Full changelog: https://hashcat.net/forum/thread-10103.html
* Sun Nov 22 2020 Jan Engelhardt <jengelh@inai.de>
- OpenCL required at runtime [boo#1177190]
* Tue Sep  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 6.1.1
  * new hash-mode plugin interface, new backend API interface,
    new algorithms
- Add system-libs.patch
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update license field.
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Add fdupes call.
- License file was shipped twice, ditch one copy.
* Wed Jan 16 2019 Robert Frohl <rfrohl@suse.com>
- hashcat v5.1.0:
  This release is mostly about expanding support for new algorithms and fixing bugs.
  Full changelog: https://hashcat.net/forum/thread-7983.html
- Remove flags.diff
* Thu Jun 30 2016 jengelh@inai.de
- Update to new upstream release oclhashcat-3.00
- Drop 0001-fixes-issue-10-compiler-warning-for-possible-memory-.patch
  (no longer applicable), add flags.diff.
* Sun Dec  6 2015 jengelh@inai.de
- Initial package for build.opensuse.org (version 2.00)
